# local_git_repo

Clone a Git repository and use POSIX extended ACLs to grant access to it.

# Prerequisites

This module depends on three external modules:

* https://forge.puppet.com/modules/puppet/posix_acl
* https://forge.puppet.com/modules/puppetlabs/stdlib
* https://forge.puppet.com/modules/puppetlabs/vcsrepo

# Usage

Example usage with one allowed group:

    $group = 'developers'
    
    local_git_repo::instance { 'myrepo':
      git_url        => 'https://git.example.org/myrepo.git',
      target_dir     => '/var/lib/repos/myrepo',
      permissions    => [ 'default:mask::rwx',
                          'mask::rwx',
                          "default:g:${group}:rwx",
                          "g:${group}:rwx", ],
    }

Example usage with two allowed groups:

    $group = 'developers'
    $another_group = 'devops'
    
    local_git_repo::instance { 'myrepo':
      git_url        => 'https://git.example.org/myrepo.git',
      target_dir     => '/var/lib/repos/myrepo',
      permissions    => [ 'default:mask::rwx',
                          'mask::rwx',
                          "default:g:${group}:rwx",
                          "g:${group}:rwx",
                          "default:g:${another_group}:rwx",
                          "g:${another_group}:rwx", ],
    }

If add additional permissions later, you need to manually set the acls for
existing files. Whatever defaults you may have set will not be automatically
propagated to directories or files that have been created prior to your
changes. Here's an example:

    setfacl -R -m 'group:devops:rwx' myrepo/
    setfacl -R -m 'default:group:devops:rwx' myrepo/

To share the Git repository with git-daemon using Git protocol (currently
Ubuntu/Debian only):

    class { 'local_git_repo::gitdaemon':
      base_path => '/var/lib/repos',
      directory => '/var/lib/repos/myrepo',
    }

The *directory* parameter is the directory whitelist. Directories not on the
whitelist will not be exported by git-daemon. Based on git-daemon documentation
it should accept a string with multiple directories separated by a space.
